Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(406)

Unified Diff: ios/chrome/browser/web_state_list/web_state_list_serialization.h

Issue 2808773004: [ios] Change WebStateList serialization method to use SessionWindowIOS. (Closed)
Patch Set: Rename //ios/chrome/browser/sessions:session_window_ios target. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/web_state_list/web_state_list_serialization.h
diff --git a/ios/chrome/browser/web_state_list/web_state_list_serialization.h b/ios/chrome/browser/web_state_list/web_state_list_serialization.h
index a6d18fecc0cb48422e4a90af604e5753041d114e..f07dcda5d016e2eface976ac80aa7e65f946be61 100644
--- a/ios/chrome/browser/web_state_list/web_state_list_serialization.h
+++ b/ios/chrome/browser/web_state_list/web_state_list_serialization.h
@@ -12,6 +12,7 @@
#include "base/callback_forward.h"
@class CRWSessionStorage;
+@class SessionWindowIOS;
class WebStateList;
namespace web {
@@ -23,13 +24,12 @@ using WebStateFactory =
base::RepeatingCallback<std::unique_ptr<web::WebState>(CRWSessionStorage*)>;
// Returns an array of serialised sessions.
-NSArray<CRWSessionStorage*>* SerializeWebStateList(
- WebStateList* web_state_list);
+SessionWindowIOS* SerializeWebStateList(WebStateList* web_state_list);
-// Restores |sessions| into |web_state_list| using |web_state_factory| for
-// creating the restored WebStates.
+// Restores a |web_state_list| from |session_window| using |web_state_factory|
+// to create the restored WebStates.
void DeserializeWebStateList(WebStateList* web_state_list,
- NSArray<CRWSessionStorage*>* sessions,
+ SessionWindowIOS* session_window,
const WebStateFactory& web_state_factory);
#endif // IOS_CHROME_BROWSER_WEB_STATE_LIST_WEB_STATE_LIST_SERIALIZATION_H_
« no previous file with comments | « ios/chrome/browser/web_state_list/BUILD.gn ('k') | ios/chrome/browser/web_state_list/web_state_list_serialization.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698